@@ -1,13 +1,10 @@
-use syn::{
-    Meta, NestedMeta,
-};
-
+use syn::{Meta, NestedMeta};
 
 /// Iterates over an iterator of syn::NestedMeta,
 /// unwrapping it into a syn::Meta and passing it into the `f` closure.
-pub fn with_nested_meta<I, F>(attr_name: &str, iter: I, mut f: F)->Result<(),syn::Error>
+pub fn with_nested_meta<I, F>(attr_name: &str, iter: I, mut f: F) -> Result<(), syn::Error>
 where
-    F: FnMut(Meta)->Result<(),syn::Error>,
+    F: FnMut(Meta) -> Result<(), syn::Error>,
     I: IntoIterator<Item = NestedMeta>,
 {
     for repr in iter {
@@ -26,5 +23,3 @@ where
     }
     Ok(())
 }
-
-
