@@ -1,12 +1,12 @@
 use std::{
-    cmp::{Eq,PartialEq},
-    hash::{Hash,Hasher},
-    ops::{Deref},
+    cmp::{Eq, PartialEq},
+    hash::{Hash, Hasher},
+    ops::Deref,
 };
 
 use core_extensions::SelfOps;
 use regex::Regex;
-use serde::de::{Deserialize,Deserializer,Error as deError};
+use serde::de::{Deserialize, Deserializer, Error as deError};
 
 #[derive(Clone, Debug)]
 pub struct RegexWrapper(pub Regex);
@@ -17,7 +17,6 @@ impl From<Regex> for RegexWrapper {
     }
 }
 
-
 impl Hash for RegexWrapper {
     #[inline]
     fn hash<H: Hasher>(&self, state: &mut H) {
@@ -35,7 +34,7 @@ impl PartialEq for RegexWrapper {
 
 impl Deref for RegexWrapper {
     type Target = Regex;
-    
+
     #[inline]
     fn deref(&self) -> &Self::Target {
         &self.0
@@ -53,4 +52,4 @@ impl<'de> Deserialize<'de> for RegexWrapper {
             .map_err(|e| format!("{}", e))
             .map_err(D::Error::custom)
     }
-}
\ No newline at end of file
+}
